Flask-Annex |PyPI|
==================

Efficient integration of external storage services for
`Flask <http://flask.pocoo.org/>`__.

.. |PyPI| image:: https://img.shields.io/pypi/v/Flask-Annex.svg
   :target: https://pypi.python.org/pypi/Flask-Annex
